@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,6 +11,12 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License
 
+from braket.device_schema.blackbird_device_action_properties import (  # noqa: F401
+    BlackbirdDeviceActionProperties,
+)
+from braket.device_schema.continuous_variable_qpu_paradigm_properties_v1 import (  # noqa: F401
+    ContinuousVariableQpuParadigmProperties,
+)
 from braket.device_schema.device_action_properties import (  # noqa: F401
     DeviceActionProperties,
     DeviceActionType,
@@ -29,3 +35,10 @@ from braket.device_schema.gate_model_qpu_paradigm_properties_v1 import (  # noqa
 from braket.device_schema.jaqcd_device_action_properties import (  # noqa: F401
     JaqcdDeviceActionProperties,
 )
+from braket.device_schema.openqasm_device_action_properties import (  # noqa: F401
+    OpenQASMDeviceActionProperties,
+)
+from braket.device_schema.result_type import ResultType  # noqa: F401
+from braket.device_schema.standardized_gate_model_qpu_device_properties_v1 import (  # noqa: F401
+    StandardizedGateModelQpuDeviceProperties,
+)
