@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -12,7 +12,7 @@
 # language governing permissions and limitations under the License.
 
 from enum import Enum
-from typing import List
+from typing import List, Union
 
 from pydantic import BaseModel
 
@@ -22,7 +22,9 @@ class DeviceActionType(str, Enum):
     These are the actions supported by Braket.
     """
 
+    OPENQASM = "braket.ir.openqasm.program"
     JAQCD = "braket.ir.jaqcd.program"
+    BLACKBIRD = "braket.ir.blackbird.program"
     ANNEALING = "braket.ir.annealing.problem"
 
 
@@ -31,8 +33,9 @@ class DeviceActionProperties(BaseModel):
     This class defines the actions that can be performed by a device
 
     Attributes:
-        version: List of versions for the actions the device supports
-        actionType: Enum for the action type. Type of the action to be performed.
+        version (List[str]): List of versions for the actions the device supports
+        actionType (Union[DeviceActionType, str]): Enum for the action type.
+             Type of the action to be performed.
 
     Examples:
         >>> import json
@@ -44,4 +47,4 @@ class DeviceActionProperties(BaseModel):
     """
 
     version: List[str]
-    actionType: DeviceActionType
+    actionType: Union[DeviceActionType, str]
