@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,7 +11,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from typing import Dict
+from typing import Dict, Union
 
 from pydantic import BaseModel
 
@@ -25,10 +25,11 @@ class DeviceCapabilities(BaseModel):
     across all the devices
 
     Attributes:
-        service: properties which are common to the Braket service
-        action: Map of the action to its properties
-        deviceParameters: It is the json schema of the deviceParameters for each device. for
-            example the deviceParameter for IonqDeviceCapabilities will be
+        service (DeviceServiceProperties): properties which are common to the Braket service
+        action (Dict[Union[DeviceActionType, str], DeviceActionProperties]): Map of the action
+             to its properties
+        deviceParameters (dict): The json schema of the deviceParameters for each device.
+             For example, the deviceParameter for IonqDeviceCapabilities will be
             IonqDeviceParameters.json_schema()
 
     Examples:
@@ -71,5 +72,5 @@ class DeviceCapabilities(BaseModel):
     """
 
     service: DeviceServiceProperties
-    action: Dict[DeviceActionType, DeviceActionProperties]
+    action: Dict[Union[DeviceActionType, str], DeviceActionProperties]
     deviceParameters: dict
