@@ -1,4 +1,4 @@
-# Copyright 2019-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -16,10 +16,14 @@ from typing import Optional, Union
 from pydantic import BaseModel
 
 from braket.ir.annealing import Problem
-from braket.ir.jaqcd import Program
+from braket.ir.blackbird import Program as BlackbirdProgram
+from braket.ir.jaqcd import Program as JaqcdProgram
+from braket.ir.openqasm import Program as OpenQASMProgram
 from braket.task_result.dwave_metadata_v1 import DwaveMetadata
+from braket.task_result.oqc_metadata_v1 import OqcMetadata
 from braket.task_result.rigetti_metadata_v1 import RigettiMetadata
 from braket.task_result.simulator_metadata_v1 import SimulatorMetadata
+from braket.task_result.xanadu_metadata_v1 import XanaduMetadata
 
 
 class AdditionalMetadata(BaseModel):
@@ -36,7 +40,9 @@ class AdditionalMetadata(BaseModel):
 
     """
 
-    action: Union[Program, Problem]
+    action: Union[JaqcdProgram, OpenQASMProgram, BlackbirdProgram, Problem]
     dwaveMetadata: Optional[DwaveMetadata]
     rigettiMetadata: Optional[RigettiMetadata]
+    oqcMetadata: Optional[OqcMetadata]
+    xanaduMetadata: Optional[XanaduMetadata]
     simulatorMetadata: Optional[SimulatorMetadata]
